# eric7.Plugins.VcsPlugins.vcsMercurial.StripExtension.ProjectHelper

Module implementing the strip extension project helper.

### Global Attributes

None

### Classes

StripProjectHelper | Class implementing the strip extension project helper.

### Functions

None

## StripProjectHelper

Class implementing the strip extension project helper.

### Derived from

HgExtensionProjectHelper

### Class Attributes

None

### Class Methods

None

### Methods

StripProjectHelper | Constructor
__hgStrip | Private slot used to strip revisions from a repository.
initActions | Public method to generate the action objects.
initMenu | Public method to generate the extension menu.
menuTitle | Public method to get the menu title.

### Static Methods

None

#### StripProjectHelper (Constructor)

StripProjectHelper()

Constructor

#### StripProjectHelper.__hgStrip

__hgStrip()

Private slot used to strip revisions from a repository.

#### StripProjectHelper.initActions

initActions()

Public method to generate the action objects.

#### StripProjectHelper.initMenu

initMenu(mainMenu)

Public method to generate the extension menu.

mainMenu (QMenu)
  reference to the main menu

Return:
  populated menu

Return Type:
  QMenu

#### StripProjectHelper.menuTitle

menuTitle()

Public method to get the menu title.

Return:
  title of the menu

Return Type:
  str

Up